﻿Type=Service
Version=6.5
ModulesStructureVersion=1
B4A=true
@EndOfDesignText@
#Region  Service Attributes 
	#StartAtBoot: True
	#ExcludeFromLibrary: True
#End Region

Sub Process_Globals
	'These global variables will be declared once when the application starts.
	'These variables can be accessed from all modules.
	Dim AppOpen As Boolean		'Tracks if this service has been only run by boot and or if user open up program manually

	Dim StatusFlag As Int		'0=Disabled, 1=Monitor, 2=Countdown, 3=Suspended
	Dim StatusMsg As String		
	Dim CountTick, CountMax As Int

	Dim PhNotify As Notification
	Dim PhEvents As PhoneEvents
	Dim TMRShutdown As Timer
End Sub

Sub Service_Create
	PhEvents.Initialize("PhEvents")
	TMRShutdown.Initialize("TMRShutdown",1000)

	PhNotify.Initialize
    PhNotify.Icon = "icon_shutdown" 'folder\Objects\res\drawable
    PhNotify.Light = False
    PhNotify.Sound = False
    PhNotify.Vibrate = False
	PhNotify.AutoCancel = False
'	#IF RELEASE
'	CallSub(Main, "MinScreen")
'	#End If
End Sub

Sub Service_Start (StartingIntent As Intent)
'	Service.StartForeground(1, PhNotify)	
	If StartingIntent.Action = "android.intent.action.BOOT_COMPLETED" Then 
		AppOpen = False
		ToastMessageShow("Auto Shutdown service started", False)
	Else
		AppOpen = True
	End If
	
	LoadVars
	If StatusFlag = 0 Then
		Disable_Shutdown(True)
	Else
		Enable_Shutdown(True)
	End If
'	SaveVars	'When starting the serivce, we only want disable/enable status
End Sub

Sub Application_Error (Error As Exception, StackTrace As String) As Boolean
	Return True
End Sub

Sub Service_Destroy
	PhEvents.StopListening
	PhNotify.Cancel(1)
'	TMRShutdown.Enabled = False
'	Service.StopForeground(1)
End Sub



Sub LoadVars
	'Do not update values if timer is already counting down
	If TMRShutdown.Enabled = False Then
		StatusFlag = StateManager.GetSetting2("StatusFlag", 0)
		CountMax = StateManager.GetSetting2("CountMax", 30)
	End If
End Sub

Sub PhEvents_BatteryChanged (Level As Int, Scale As Int, Plugged As Boolean, Intent As Intent)
	If StatusFlag > 0 Then     
		If StatusFlag = 1 And Plugged = False Then		'Start the shutdown timer
			Start_Shutdown(True)
		Else If (StatusFlag = 2 Or StatusFlag = 3) And Plugged = True Then	'Re-Enabled when plugged back in
			Enable_Shutdown(False)
		End If
	End If
End Sub

Sub Disable_Shutdown(ShowApp As Boolean)
	StatusFlag = 0	
	StatusMsg = "* Disabled *"
	RefreshNotify(ShowApp)
End Sub

Sub Enable_Shutdown(ShowApp As Boolean)
	TMRShutdown.Enabled = False	'reset shutdown Timer
	StatusFlag = 1	
	StatusMsg = "Enabled: Monitoring power"
	RefreshNotify(ShowApp)
End Sub

Sub Start_Shutdown(ShowApp As Boolean)
	TMRShutdown.Enabled = True
	StatusFlag = 2
	CountTick = -1
	StatusMsg = "Shutdown: "& CountMax &" seconds"
	RefreshNotify(ShowApp)

	If IsPaused(Main) Then 	'Bring countdown app to front
		StartActivity(Main)
	End If
End Sub

Sub TMRShutdown_Tick	'Shutdown once timer is reached
	CountTick = CountTick + 1
	If (CountMax - CountTick) = 0 Then	'Counted down to 0
		PowerDown
	End If
	StatusMsg = "Shutdown: "& (CountMax-CountTick) &" seconds"
	RefreshNotify(False)
End Sub

Sub Cancel_Shutdown
	TMRShutdown.Enabled = False	'Turn off Auto Shutdown
	StatusFlag = 3
	StatusMsg = "Suspended: On battery"
	RefreshNotify(False)
End Sub

Sub RefreshNotify(ShowApp As Boolean)
	PhNotify.SetInfo("Auto Shutdown", StatusMsg, Main)
    PhNotify.Notify(1)


	'HELP 
	'Service gets to here but doesn't start Main
	If ShowApp And AppOpen And IsPaused(Main) Then		'Sometimes main doesn't load when first clicking the program open
		StartActivity(Main)
		CallSubDelayed(Main, "RefreshPanel")
		ToastMessageShow("IN here", False)
	End If



	If IsPaused(Main) = False Then
		CallSub(Main, "RefreshPanel")
	End If
End Sub

'Need to be rooted to run this SU command
Sub PowerDown
    Dim ph As Phone
    Dim Command, Runner As String
    Dim StdOut, StdErr As StringBuilder

	StateManager.SaveSettings

    StdOut.Initialize
    StdErr.Initialize
    Runner = File.Combine(File.DirInternalCache, "runner")
    Command = File.Combine(File.DirInternalCache, "command")
    File.WriteString(File.DirInternalCache, "runner", "su < " & Command)
    File.WriteString(File.DirInternalCache, "command", "su -c reboot -p")  
    ph.Shell("sh", Array As String(Runner), StdOut, StdErr)   
End Sub
